Skip to contents

Returns the path to example data files included with the cmapr package.

Usage

cmap_example_data(file = "example_transitions.csv")

Arguments

file

Character string specifying the example file name. Default is "example_transitions.csv".

Value

Character string containing the full path to the example file, or an empty string if the file does not exist.

Examples

# Get path to example transitions data
example_path <- cmap_example_data()
if (nzchar(example_path)) {
  head(readr::read_csv(example_path))
}