Reads multiple CSV files and combines them into a single tibble using either readr or vroom.
Usage
read_csvs(paths, reader = c("readr", "vroom"))Reads multiple CSV files and combines them into a single tibble using either readr or vroom.
read_csvs(paths, reader = c("readr", "vroom"))